==> psi-plus_1.3.425.orig.tar.gz: psi-plus-snapshots-1.3.425/iris/src/xmpp/xmpp-im/xmpp_bytestream.cpp <==
/*
 * bytestream_manager.cpp - base class for bytestreams over xmpp
 * Copyright (C) 2003  Justin Karneges, Rion
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 */

#include <QTimer>

#include "xmpp_bytestream.h"
#include "xmpp_client.h"

namespace XMPP
{

BytestreamManager::BytestreamManager(Client *parent)
    : QObject(parent)
{

}

BytestreamManager::~BytestreamManager()
{

}

QString BytestreamManager::genUniqueSID(const Jid &peer) const
{
    // get unused key
    QString sid;
    do {
        sid = QString("%1%2").arg(sidPrefix())
                             .arg(qrand() & 0xffff, 4, 16, QChar('0'));
    } while(!isAcceptableSID(peer, sid));
    return sid;
}

/**
 * Deletes conection in specified interval
 */
void BytestreamManager::deleteConnection(BSConnection *c, int msec)
{
    if (msec) {
        QTimer::singleShot(msec, c, SLOT(deleteLater()));
    }
    else {
        delete c;
    }
}

}

==> psi-plus_1.4.1000.orig.tar.gz: psi-plus-snapshots-1.4.1000/iris/src/xmpp/xmpp-im/xmpp_bytestream.cpp <==
/*
 * bytestream_manager.cpp - base class for bytestreams over xmpp
 * Copyright (C) 2003  Justin Karneges, Sergey Ilinykh
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

#include "xmpp_bytestream.h"

#include "xmpp_client.h"

#include <QTimer>

namespace XMPP {
BytestreamManager::BytestreamManager(Client *parent) : QObject(parent) {}

BytestreamManager::~BytestreamManager() {}

QString BytestreamManager::genUniqueSID(const Jid &peer) const
{
    // get unused key
    QString sid;
    do {
        sid = QString("%1%2").arg(sidPrefix()).arg(qrand() & 0xffff, 4, 16, QChar('0'));
    } while (!isAcceptableSID(peer, sid));
    return sid;
}

/**
 * Deletes conection in specified interval
 */
void BytestreamManager::deleteConnection(BSConnection *c, int msec)
{
    if (msec) {
        QTimer::singleShot(msec, c, SLOT(deleteLater()));
    } else {
        delete c;
    }
}
} // namespace XMPP
